@@ -1,14 +1,11 @@
-from django.conf import settings
 import sentry_sdk
 import ddtrace
 
-
 __all__ = [
     "add_event_tag",
 ]
 
-
-def add_event_tag(name, value):
+def add_event_tag(name, value, dd_scope=None):
     """
     Attempts to add an event tag for Sentry and DataDog
     """
@@ -21,9 +18,12 @@ def add_event_tag(name, value):
         pass
 
     try:
-        ddtrace.tracer.current_span().set_tag(
-            name,
-            value
-        )
+        if dd_scope:
+            dd_scope.set_tag(name,value)
+        else:      
+            ddtrace.tracer.current_span().set_tag(
+                name,
+                value
+            )
     except:
-        pass
+        pass
\ No newline at end of file
